@@ -1,21 +1,21 @@
 #!/usr/bin/env bash
 
-set -eu
-
 ## START STANDARD BUILD SCRIPT INCLUDE
 # adjust relative paths as necessary
 THIS_SCRIPT="$(readlink -f "${BASH_SOURCE[0]}")"
-. "${THIS_SCRIPT%/*}/../resources/build/build-utils.sh"
+. "${THIS_SCRIPT%/*}/../resources/build/builder.inc.sh"
 ## END STANDARD BUILD SCRIPT INCLUDE
 
+. "$KEYMAN_ROOT/resources/shellHelperFunctions.sh"
+
 ################################ Main script ################################
 
-cd "$THIS_SCRIPT_PATH"
-
 builder_describe \
   "Build Keyman for Linux." \
+  "@/resources/tools/check-markdown  test:help" \
   ":config=keyman-config             keyman-config" \
   ":engine=ibus-keyman               ibus-keyman" \
+  ":help                             Online documentation" \
   ":service=keyman-system-service    keyman-system-service" \
   "clean" \
   "configure" \
@@ -40,3 +40,4 @@ test_action() {
 }
 
 builder_run_action test test_action
+builder_run_action        test:help    check-markdown  "$KEYMAN_ROOT/linux/docs/help"
