@@ -5,6 +5,9 @@ import os
 from keyman_config.gsettings import GSettings
 
 
+# pylint: disable=global-statement
+
+
 class GnomeKeyboardsUtil():
     def __init__(self):
         self.input_sources = GSettings('org.gnome.desktop.input-sources')
@@ -21,23 +24,29 @@ class GnomeKeyboardsUtil():
         self.input_sources.set('sources', sources, 'a(ss)')
 
 
-__is_gnome_shell = None
+# pylint: disable=invalid-name
+__is_gnome_desktop = None
 
 
-def is_gnome_shell():
-    global __is_gnome_shell
+def is_gnome_desktop():
+    '''
+    Returns true if system is running Gnome shell or another Gnome desktop
+    that stores keyboard data under `org.gnome.desktop.input-sources`.
+    '''
+    global __is_gnome_desktop
 
-    if __is_gnome_shell is None:
+    if __is_gnome_desktop is None:
         code = os.system('pidof gnome-shell >/dev/null 2>&1')
-        __is_gnome_shell = (code == 0)
-    return __is_gnome_shell
+        gnome_env = ('XDG_CURRENT_DESKTOP' in os.environ) and ('gnome' in os.environ['XDG_CURRENT_DESKTOP'].lower())
+        __is_gnome_desktop = (code == 0) or gnome_env
+    return __is_gnome_desktop
 
 
 def _reset_gnome_shell():
     # used in unit tests
-    global __is_gnome_shell
+    global __is_gnome_desktop
 
-    __is_gnome_shell = None
+    __is_gnome_desktop = None
 
 
 def get_ibus_keyboard_id(keyboard, packageDir, language=None, ignore_language=False):
